@@ -277,6 +277,7 @@ causal_survival_forest <- function(X, Y, W, D,
     # The survival function conditioning on being treated S(t, x, 1) estimated with an "S-learner".
     # Computing OOB estimates for modified training samples is not a workflow we have implemented,
     # so we do it with a manual workaround here (deleting/re-inserting precomputed predictions)
+    grf.verbose <- options("grf.verbose" = FALSE)
     .predictions <- sf.survival[["predictions"]]
     sf.survival[["predictions"]] <- NULL
     sf.survival[["X.orig"]][, ncol(X) + 1] <- rep(1, nrow(X))
@@ -286,6 +287,7 @@ causal_survival_forest <- function(X, Y, W, D,
     S0.hat <- predict(sf.survival, num.threads = num.threads)$predictions
     sf.survival[["X.orig"]][, ncol(X) + 1] <- W
     sf.survival[["predictions"]] <- .predictions
+    options(grf.verbose)
     if (target == "RMST") {
       Y.hat <- W.hat * expected_survival(S1.hat, sf.survival$failure.times) +
         (1 - W.hat) * expected_survival(S0.hat, sf.survival$failure.times)
@@ -334,7 +336,7 @@ causal_survival_forest <- function(X, Y, W, D,
                   "such that the probability of observing an event past the maximum follow-up time ",
                   "is at least M (i.e. P(T > horizon | X) > M).",
                   "This warning appears when M is less than 0.05, at which point causal survival forest",
-                  "can not be expected to deliver reliable estimates."), immediate. = TRUE)
+                  "can not be expected to deliver reliable estimates."))
   } else if (target == "RMST" && any(C.Y.hat < 0.2)) {
     warning(paste("Estimated censoring probabilities are lower than 0.2",
                   "- an identifying assumption is that there exists a fixed positive constant M",
@@ -343,7 +345,7 @@ causal_survival_forest <- function(X, Y, W, D,
   } else if (target == "survival.probability" && any(C.Y.hat <= 0.001)) {
     warning(paste("Estimated censoring probabilities go as low as:", round(min(C.Y.hat), 5),
                   "- forest estimates will likely be very unstable, a larger target `horizon`",
-                  "is recommended."), immediate. = TRUE)
+                  "is recommended."))
   } else if (target == "survival.probability" && any(C.Y.hat < 0.05)) {
     warning(paste("Estimated censoring probabilities are lower than 0.05",
                   "and forest estimates may not be stable. Using a smaller target `horizon`",
@@ -378,7 +380,8 @@ causal_survival_forest <- function(X, Y, W, D,
                compute.oob.predictions = compute.oob.predictions,
                num.threads = num.threads,
                seed = seed,
-               legacy.seed = get_legacy_seed())
+               legacy.seed = get_legacy_seed(),
+               verbose = get_verbose())
 
   forest <- do.call.rcpp(causal_survival_train, c(data, args))
   class(forest) <- c("causal_survival_forest", "grf")
@@ -487,7 +490,8 @@ predict.causal_survival_forest <- function(object,
 
   args <- list(forest.object = forest.short,
                num.threads = num.threads,
-               estimate.variance = estimate.variance)
+               estimate.variance = estimate.variance,
+               verbose = get_verbose())
 
   if (!is.null(newdata)) {
     validate_newdata(newdata, X, allow.na = TRUE)
