@@ -227,7 +227,8 @@ lm_forest <- function(X, Y, W,
                compute.oob.predictions = compute.oob.predictions,
                num.threads = num.threads,
                seed = seed,
-               legacy.seed = get_legacy_seed())
+               legacy.seed = get_legacy_seed(),
+               verbose = get_verbose())
 
   forest <- do.call.rcpp(multi_causal_train, c(data, args))
   class(forest) <- c("lm_forest", "grf")
@@ -348,7 +349,8 @@ predict.lm_forest <- function(object,
                num.outcomes = num.outcomes,
                num.treatments = num.W,
                num.threads = num.threads,
-               estimate.variance = estimate.variance)
+               estimate.variance = estimate.variance,
+               verbose = get_verbose())
 
   if (!is.null(newdata)) {
     validate_newdata(newdata, X, allow.na = TRUE)
