@@ -50,7 +50,10 @@ Rcpp::List causal_train(const Rcpp::NumericMatrix& train_matrix,
                         bool compute_oob_predictions,
                         unsigned int num_threads,
                         unsigned int seed,
-                        bool legacy_seed) {
+                        bool legacy_seed,
+                        bool verbose) {
+  grf::runtime_context.forest_name = "causal";
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   ForestTrainer trainer = instrumental_trainer(reduced_form_weight, stabilize_splits);
 
   Data data = RcppUtilities::convert_data(train_matrix);
@@ -67,6 +70,7 @@ Rcpp::List causal_train(const Rcpp::NumericMatrix& train_matrix,
 
   std::vector<Prediction> predictions;
   if (compute_oob_predictions) {
+    grf::runtime_context.verbose_stream = nullptr;
     ForestPredictor predictor = instrumental_predictor(num_threads);
     predictions = predictor.predict_oob(forest, data, false);
   }
@@ -82,7 +86,9 @@ Rcpp::List causal_predict(const Rcpp::List& forest_object,
                           size_t treatment_index,
                           const Rcpp::NumericMatrix& test_matrix,
                           unsigned int num_threads,
-                          bool estimate_variance) {
+                          bool estimate_variance,
+                          bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data train_data = RcppUtilities::convert_data(train_matrix);
   train_data.set_outcome_index(outcome_index);
   train_data.set_treatment_index(treatment_index);
@@ -104,7 +110,9 @@ Rcpp::List causal_predict_oob(const Rcpp::List& forest_object,
                               size_t outcome_index,
                               size_t treatment_index,
                               unsigned int num_threads,
-                              bool estimate_variance) {
+                              bool estimate_variance,
+                              bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data data = RcppUtilities::convert_data(train_matrix);
   data.set_outcome_index(outcome_index);
   data.set_treatment_index(treatment_index);
@@ -129,7 +137,9 @@ Rcpp::List ll_causal_predict(const Rcpp::List& forest_object,
                              bool ll_weight_penalty,
                              std::vector<size_t> linear_correction_variables,
                              unsigned int num_threads,
-                             bool estimate_variance) {
+                             bool estimate_variance,
+                             bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data train_data = RcppUtilities::convert_data(train_matrix);
   train_data.set_outcome_index(outcome_index);
   train_data.set_treatment_index(treatment_index);
@@ -155,7 +165,9 @@ Rcpp::List ll_causal_predict_oob(const Rcpp::List& forest_object,
                                  bool ll_weight_penalty,
                                  std::vector<size_t> linear_correction_variables,
                                  unsigned int num_threads,
-                                 bool estimate_variance) {
+                                 bool estimate_variance,
+                                 bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data data = RcppUtilities::convert_data(train_matrix);
 
   data.set_outcome_index(outcome_index);
