@@ -51,7 +51,10 @@ Rcpp::List causal_survival_train(const Rcpp::NumericMatrix& train_matrix,
                                  bool compute_oob_predictions,
                                  unsigned int num_threads,
                                  unsigned int seed,
-                                 bool legacy_seed) {
+                                 bool legacy_seed,
+                                 bool verbose) {
+  grf::runtime_context.forest_name = "causal survival";
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   ForestTrainer trainer = causal_survival_trainer(stabilize_splits);
 
   Data data = RcppUtilities::convert_data(train_matrix);
@@ -70,6 +73,7 @@ Rcpp::List causal_survival_train(const Rcpp::NumericMatrix& train_matrix,
 
   std::vector<Prediction> predictions;
   if (compute_oob_predictions) {
+    grf::runtime_context.verbose_stream = nullptr;
     ForestPredictor predictor = causal_survival_predictor(num_threads);
     predictions = predictor.predict_oob(forest, data, false);
   }
@@ -82,7 +86,9 @@ Rcpp::List causal_survival_predict(const Rcpp::List& forest_object,
                                    const Rcpp::NumericMatrix& train_matrix,
                                    const Rcpp::NumericMatrix& test_matrix,
                                    unsigned int num_threads,
-                                   bool estimate_variance) {
+                                   bool estimate_variance,
+                                   bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data train_data = RcppUtilities::convert_data(train_matrix);
   Data data = RcppUtilities::convert_data(test_matrix);
 
@@ -99,7 +105,9 @@ Rcpp::List causal_survival_predict(const Rcpp::List& forest_object,
 Rcpp::List causal_survival_predict_oob(const Rcpp::List& forest_object,
                                        const Rcpp::NumericMatrix& train_matrix,
                                        unsigned int num_threads,
-                                       bool estimate_variance) {
+                                       bool estimate_variance,
+                                       bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data data = RcppUtilities::convert_data(train_matrix);
 
   Forest forest = RcppUtilities::deserialize_forest(forest_object);
