@@ -47,7 +47,10 @@ Rcpp::List quantile_train(std::vector<double> quantiles,
                           bool compute_oob_predictions,
                           int num_threads,
                           unsigned int seed,
-                          bool legacy_seed) {
+                          bool legacy_seed,
+                          bool verbose) {
+  grf::runtime_context.forest_name = regression_splitting ? "regression" : "quantile";
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   ForestTrainer trainer = regression_splitting
       ? regression_trainer()
       : quantile_trainer(quantiles);
@@ -61,6 +64,7 @@ Rcpp::List quantile_train(std::vector<double> quantiles,
 
   std::vector<Prediction> predictions;
   if (compute_oob_predictions) {
+    grf::runtime_context.verbose_stream = nullptr;
     ForestPredictor predictor = quantile_predictor(num_threads, quantiles);
     predictions = predictor.predict_oob(forest, data, false);
   }
@@ -74,7 +78,9 @@ Rcpp::NumericMatrix quantile_predict(const Rcpp::List& forest_object,
                                      const Rcpp::NumericMatrix& train_matrix,
                                      size_t outcome_index,
                                      const Rcpp::NumericMatrix& test_matrix,
-                                     unsigned int num_threads) {
+                                     unsigned int num_threads,
+                                     bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data train_data = RcppUtilities::convert_data(train_matrix);
   Data data = RcppUtilities::convert_data(test_matrix);
   train_data.set_outcome_index(outcome_index);
@@ -93,7 +99,9 @@ Rcpp::NumericMatrix quantile_predict_oob(const Rcpp::List& forest_object,
                                          std::vector<double> quantiles,
                                          const Rcpp::NumericMatrix& train_matrix,
                                          size_t outcome_index,
-                                         unsigned int num_threads) {
+                                         unsigned int num_threads,
+                                         bool verbose) {
+  grf::runtime_context.verbose_stream = verbose ? &Rcpp::Rcout : nullptr;
   Data data = RcppUtilities::convert_data(train_matrix);
   data.set_outcome_index(outcome_index);
 
