@@ -20,10 +20,11 @@
 #ifndef GRF_DEFAULTPREDICTIONCOLLECTOR_H
 #define GRF_DEFAULTPREDICTIONCOLLECTOR_H
 
+#include <atomic>
 
+#include "commons/ProgressBar.h"
 #include "forest/Forest.h"
 #include "prediction/collector/PredictionCollector.h"
-#include "prediction/collector/SampleWeightComputer.h"
 #include "prediction/DefaultPredictionStrategy.h"
 
 namespace grf {
@@ -53,12 +54,13 @@ private:
                                                     const std::vector<std::vector<bool>>& valid_trees_by_sample,
                                                     bool estimate_variance,
                                                     size_t start,
-                                                    size_t num_samples) const;
+                                                    size_t num_samples,
+                                                    ProgressBar& progress_bar,
+                                                    std::atomic<bool>& user_interrupt_flag) const;
 
   void validate_prediction(size_t sample, const Prediction& prediction) const;
 
   std::unique_ptr<DefaultPredictionStrategy> strategy;
-  SampleWeightComputer weight_computer;
   uint num_threads;
 };
 
