@@ -19,6 +19,7 @@
 
 #include <future>
 #include <stdexcept>
+#include <thread>
 
 #include "prediction/collector/OptimizedPredictionCollector.h"
 #include "commons/utility.h"
@@ -35,7 +36,10 @@ std::vector<Prediction> OptimizedPredictionCollector::collect_predictions(const
                                                                           const std::vector<std::vector<bool>>& valid_trees_by_sample,
                                                                           bool estimate_variance,
                                                                           bool estimate_error) const {
+  std::atomic<bool> user_interrupt_flag {false};
+
   size_t num_samples = data.get_num_rows();
+  ProgressBar progress_bar(num_samples, "prediction [collection]: ");
   std::vector<uint> thread_ranges;
   split_sequence(thread_ranges, 0, static_cast<uint>(num_samples - 1), num_threads);
 
@@ -60,15 +64,48 @@ std::vector<Prediction> OptimizedPredictionCollector::collect_predictions(const
                                  estimate_variance,
                                  estimate_error,
                                  start_index,
-                                 num_samples_batch));
+                                 num_samples_batch,
+                                 std::ref(progress_bar),
+                                 std::ref(user_interrupt_flag)));
   }
 
+  // Periodically check for user interrupts + update progress bar while threads are working.
+  bool working = true;
+  while (working) {
+    try {
+      grf::runtime_context.interrupt_handler();
+      progress_bar.update();
+    } catch (...) {
+      user_interrupt_flag = true;
+      // Adhere to good C++ hygiene and clean up the futures before rethrowing
+      for (auto& future : futures) {
+        if (future.valid()) {
+          try { future.get(); } catch (...) {}
+        }
+      }
+      throw;
+    }
+    // Check if we can stop working
+    working = false;
+    for (const auto& future : futures) {
+      if (future.wait_for(std::chrono::milliseconds(0)) != std::future_status::ready) {
+        working = true;
+        break;
+      }
+    }
+    if (working) {
+      std::this_thread::sleep_for(std::chrono::milliseconds(1));
+    }
+  }
+
+  // Collect the final results
   for (auto& future : futures) {
     std::vector<Prediction> thread_predictions = future.get();
     predictions.insert(predictions.end(),
                        std::make_move_iterator(thread_predictions.begin()),
                        std::make_move_iterator(thread_predictions.end()));
   }
+  progress_bar.final_update();
 
   return predictions;
 }
@@ -81,7 +118,9 @@ std::vector<Prediction> OptimizedPredictionCollector::collect_predictions_batch(
                                                                                 bool estimate_variance,
                                                                                 bool estimate_error,
                                                                                 size_t start,
-                                                                                size_t num_samples) const {
+                                                                                size_t num_samples,
+                                                                                ProgressBar& progress_bar,
+                                                                                std::atomic<bool>& user_interrupt_flag) const {
   size_t num_trees = forest.get_trees().size();
   bool record_leaf_values = estimate_variance || estimate_error;
 
@@ -89,6 +128,9 @@ std::vector<Prediction> OptimizedPredictionCollector::collect_predictions_batch(
   predictions.reserve(num_samples);
 
   for (size_t sample = start; sample < num_samples + start; ++sample) {
+    if (user_interrupt_flag) {
+      return std::vector<Prediction>();
+    }
     std::vector<double> average_value;
     std::vector<std::vector<double>> leaf_values;
     if (record_leaf_values) {
@@ -149,6 +191,7 @@ std::vector<Prediction> OptimizedPredictionCollector::collect_predictions_batch(
 
     validate_prediction(sample, prediction);
     predictions.push_back(prediction);
+    progress_bar.increment(1);
   }
   return predictions;
 }
